#!/bin/bash
set -x 
source ./config.ini
[[ ! -f ./config.ini ]] && exit

init(){
rm -rf libs
tar xfp libs.tar.gz -C $root_path
useradd -s /sbin/nologin -M nginx
}

yum_i(){
yum -y install cronie patch glibc make pcre pcre-devel glib glib-develpatch net-tools openssh-server openssh-clients sudo socat telnet iproute bind-utils pcre pcre-devel openssl openssl-devel gcc gcc-c++ autoconf automake zlib-devel libxml2 libxml2-dev libxslt-devel gd-devel perl-devel perl-ExtUtils-Embed GeoIP GeoIP-devel GeoIP-data 
}

luajit_i(){
cd $root_path/libs/$luajit_version
make clean
rm -rf $luajit_plugin
make PREFIX=$luajit_plugin 
make install PREFIX=$luajit_plugin 
make
make install
rm -rf /usr/lib64/libluajit-5.1.so.2
cp $luajit_plugin/lib/libluajit-5.1.so.2 /usr/lib64/
}

luajit_c(){
cat > /etc/profile.d/luajit.sh << EOF
#!/bin/bash
export INSTALL_TOP_SHARE=$luajit_plugin/share/lua/5.1
export INSTALL_TOP_LIB=$luajit_plugin/lib/lua/5.1
export LUAJIT_LIB=$luajit_plugin/lib
export LUAJIT_INC=$luajit_plugin/include/luajit-2.0
EOF
}

nginx_i(){
source /etc/profile.d/luajit.sh
cd $root_path/libs/$nginx_version
make clean
rm -rf $nginx_path/{conf,html,logs,modules,run,sbin}
patch -p1 < ../nginx_upstream_check_module-master/check_1.12.1+.patch
./configure --prefix=$nginx_path --sbin-path=$nginx_path/sbin/nginx --modules-path=$nginx_path/modules --conf-path=$nginx_path/conf/nginx.conf --error-log-path=$nginx_path/logs/error.log --http-log-path=$nginx_path/logs/access.log --pid-path=$nginx_path/run/nginx.pid --lock-path=$nginx_path/run/nginx.lock --http-client-body-temp-path=$nginx_path/tmp/client_body --http-proxy-temp-path=$nginx_path/tmp/proxy --http-fastcgi-temp-path=$nginx_path/tmp/fastcgi --http-uwsgi-temp-path=$nginx_path/tmp/uwsgi --http-scgi-temp-path=$nginx_path/tmp/scgi --user=nginx --group=nginx --with-file-aio --with-ipv6 --with-http_ssl_module --with-http_v2_module --with-http_realip_module --with-http_addition_module --with-http_xslt_module=dynamic --with-http_image_filter_module=dynamic --with-http_geoip_module=dynamic --with-http_sub_module --with-http_dav_module --with-http_flv_module --with-http_mp4_module --with-http_gunzip_module --with-http_gzip_static_module --with-http_random_index_module --with-http_secure_link_module --with-http_degradation_module --with-http_slice_module --with-http_stub_status_module --with-http_perl_module=dynamic --with-mail=dynamic --with-mail_ssl_module --add-module=$root_path/libs/ngx_devel_kit-master --add-module=$root_path/libs/nginx-upload-module-2.2 --add-module=$root_path/libs/nginx-upload-progress-module-master --add-module=$root_path/libs/lua-nginx-module-0.10.9rc6 --add-module=$root_path/libs/nginx_upstream_check_module-master --add-module=$root_path/libs/nginx-http-concat-1.2.2 --with-pcre --with-pcre-jit --with-stream=dynamic --with-stream_ssl_module --with-debug --with-ld-opt="-Wl,-E,-rpath,$luajit_plugin/lib" --with-cc-opt="-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector --param=ssp-buffer-size=4 -m64 -mtune=generic"
make -j2 
make install
}

service_c(){
cat > /usr/lib/systemd/system/nginx.service <<EOF
[Unit]
Description=nginx - high performance web server
Documentation=http://nginx.org/en/docs/
After=network.target remote-fs.target nss-lookup.target
[Service]
Type=forking
PIDFile=/var/run/nginx.pid
ExecStartPre=$nginx_path/sbin/nginx -t -c $nginx_path/conf/nginx.conf
ExecStart=$nginx_path/sbin/nginx -c $nginx_path/conf/nginx.conf
ExecReload=/bin/kill -s HUP $MAINPID
ExecStop=/bin/kill -s QUIT $MAINPID
PrivateTmp=true
[Install]
WantedBy=multi-user.target
EOF
systemctl daemon-reload
systemctl enable nginx
}

nginx_c(){
mkdir -p $nginx_path/conf/conf.d
mkdir -p /data/nginx/error
mkdir -p /data/nginx/cache/{cache,tmp}  
mkdir -p /data/nginx/logs
mkdir -p /data/nginx/tmp
echo 404 > /data/nginx/error/404.html
echo hello > /data/nginx/error/index.html
/bin/cp -rf $root_path/conf/nginx.conf $nginx_path/conf/nginx.conf
/bin/cp -rf $root_path/conf/test.conf $nginx_path/conf/conf.d
$nginx_path/sbin/nginx -t -c $nginx_path/conf/nginx.conf
}

bash_rc(){
echo -e "export PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:$nginx_path/sbin" >/etc/profile.d/ng.sh
source /etc/profile.d/ng.sh
}

log_c(){
rm -rf $nginx_path/crontab
mkdir -p $nginx_path/crontab
cat > $nginx_path/crontab/nginx_log.sh <<EOF
#!/bin/bash
logs_path="/data/nginx/logs"
mv \$logs_path/access.log \$logs_path/access.\$(date -d "1 hours ago" +"%Y-%m-%d-%H").log
if [ -f $nginx_path/run/nginx.pid ]; then
    kill -USR1 \`cat $nginx_path/run/nginx.pid\`
fi
if [ -f \$logs_path/access.\$(date -d "2 hours ago" +"%Y-%m-%d-%H").log ]; then
    gzip \$logs_path/access.\$(date -d "2 hours ago" +"%Y-%m-%d-%H").log
fi
/bin/find \$logs_path -name *.gz -mtime +15 -type f |xargs rm -rf {};
EOF
chmod +x $nginx_path/crontab/nginx_log.sh
echo  "00 */1 * * * $nginx_path/crontab/nginx_log.sh" >>/var/spool/cron/root
crontab -l
}

init
yum_i
luajit_i
luajit_c
nginx_i
service_c
nginx_c
log_c
bash_rc
